@@ -92,10 +92,11 @@ from kivy.lang import Builder, Observable, global_idmap
 from kivy.metrics import sp                                                                 # type: ignore
 # pylint: disable=no-name-in-module
 from kivy.properties import (                                                               # type: ignore
-    BooleanProperty, DictProperty, ListProperty, ObjectProperty, StringProperty)
+    BooleanProperty, DictProperty, ListProperty, NumericProperty, ObjectProperty, StringProperty)
 from kivy.uix.behaviors import ButtonBehavior, ToggleButtonBehavior                         # type: ignore
 from kivy.uix.bubble import BubbleButton                                                    # type: ignore
 from kivy.uix.dropdown import DropDown                                                      # type: ignore
+from kivy.uix.label import Label                                                            # type: ignore
 from kivy.uix.popup import Popup                                                            # type: ignore
 from kivy.uix.slider import Slider                                                          # type: ignore
 import kivy.uix.textinput                                                                   # type: ignore
@@ -122,7 +123,7 @@ from ae.kivy_help import HelpBehavior, HelpLayout, HelpToggler
 from ae.kivy_relief_canvas import ReliefCanvas                                              # type: ignore
 
 
-__version__ = '0.1.54'
+__version__ = '0.1.58'
 
 
 kivy.require('2.0.0')
@@ -188,7 +189,7 @@ Builder.load_string('''\
             pos: self.pos
             size: self.size
 
-<ImageLabel@ReliefCanvas+Label>:
+<ImageLabel>:
     ellipse_fill_ink: 1.0, 1.0, 1.0, 0.0
     ellipse_fill_pos: ()
     ellipse_fill_size: ()
@@ -216,6 +217,24 @@ Builder.load_string('''\
         Ellipse:
             pos: self.ellipse_fill_pos or self.default_pos or self.pos
             size: self.ellipse_fill_size or self.default_size or self.size
+    canvas.after:
+        StencilPush
+        Rectangle:
+            pos: self.pos
+            size: self.size
+        StencilUse
+        Color:
+            rgba: 0.99, 0.96, 0.09, 1.0 - self._touch_anim
+        Ellipse:
+            pos:
+                round(self.center_x - self.width * self._touch_anim / 2.01), \
+                round(self.center_y - self.height * self._touch_anim / 2.01)
+            size: round(self.width * self._touch_anim), round(self.height * self._touch_anim)
+        StencilUnUse
+        Rectangle:
+            pos: self.pos
+            size: self.size
+        StencilPop
     Image:
         id: themeLabelImage
         source: root.source
@@ -336,11 +355,11 @@ def ensure_tap_kwargs_refs(init_kwargs: Dict[str, Any], tap_widget: Widget):
             tap_kwargs['popup_kwargs'] = dict()
         popup_kwargs = tap_kwargs['popup_kwargs']
         if 'parent' not in popup_kwargs:
-            popup_kwargs['parent'] = tap_widget
+            popup_kwargs['parent'] = tap_kwargs['tap_widget']
 
     """
     init_kwargs['tap_kwargs'] = tap_kwargs = init_kwargs.get('tap_kwargs', dict())
-    tap_kwargs['tap_widget'] = tap_kwargs.get('tap_widget', tap_widget)
+    tap_kwargs['tap_widget'] = tap_widget = tap_kwargs.get('tap_widget', tap_widget)
     tap_kwargs['popup_kwargs'] = popup_kwargs = tap_kwargs.get('popup_kwargs', dict())
     popup_kwargs['parent'] = popup_kwargs.get('parent', tap_widget)
 
@@ -350,7 +369,12 @@ class AppStateSlider(HelpBehavior, Slider):
     app_state_name = StringProperty()   #: name of the app state to be changed by this slider value
 
 
-class ImageButton(ButtonBehavior, Factory.ImageLabel):                                               # pragma: no cover
+class ImageLabel(ReliefCanvas, Label):
+    """ base label used for all labels and buttons. """
+    _touch_anim = NumericProperty(1.0)
+
+
+class ImageButton(ButtonBehavior, ImageLabel):                                               # pragma: no cover
     """ theme-able button base class with additional events for double/triple/long touches.
 
     :Events:
@@ -382,6 +406,8 @@ class ImageButton(ButtonBehavior, Factory.ImageLabel):
         :return:        True if event got processed/used.
         """
         if not self.disabled and self.collide_point(touch.x, touch.y):
+            self._touch_anim = 0.0
+            Animation(_touch_anim=1.0, t='out_quad', d=0.39).start(self)
             is_triple = touch.is_triple_tap
             if is_triple or touch.is_double_tap:
                 # pylint: disable=maybe-no-member
@@ -390,7 +416,7 @@ class ImageButton(ButtonBehavior, Factory.ImageLabel):
                 return True
             # pylint: disable=maybe-no-member
             touch.ud['long_touch_handler'] = long_touch_handler = lambda dt: self.dispatch('on_long_tap', touch)
-            Clock.schedule_once(long_touch_handler, 2.4)
+            Clock.schedule_once(long_touch_handler, 0.99)
         return super().on_touch_down(touch)         # does touch.grab(self)
 
     @staticmethod
@@ -735,7 +761,7 @@ class FlowPopup(ContainerChildrenAutoWidthBehavior, DynamicChildrenBehavior, Rel
         return super().on_touch_down(touch)
 
 
-class FlowToggler(HelpBehavior, ToggleButtonBehavior, Factory.ImageLabel):                          # pragma: no cover
+class FlowToggler(HelpBehavior, ToggleButtonBehavior, ImageLabel):                              # pragma: no cover
     """ toggle button changing flow id. """
     tap_flow_id = StringProperty()          #: the new flow id that will be set when this toggle button get released
     tap_kwargs = DictProperty()             #: kwargs dict passed to event handler (change_flow) when button get tapped
@@ -744,6 +770,17 @@ class FlowToggler(HelpBehavior, ToggleButtonBehavior, Factory.ImageLabel):
         ensure_tap_kwargs_refs(kwargs, self)
         super().__init__(**kwargs)
 
+    def on_touch_down(self, touch: MotionEvent) -> bool:
+        """ touch animation.
+
+        :param touch:   motion/touch event data.
+        :return:        True if event got processed/used.
+        """
+        if not self.disabled and self.collide_point(touch.x, touch.y):
+            self._touch_anim = 0.0
+            Animation(_touch_anim=1.0, t='out_quad', d=0.39).start(self)
+        return super().on_touch_down(touch)
+
 
 class FrameworkApp(App):
     """ kivy framework app class proxy redirecting events and callbacks to the main app class instance. """
